PRO blockfill
; Program to show plotting blockfill colours

; read in the data
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'temp')
NCDF_VARGET, fid, varid, data
varid=NCDF_VARID(fid,'longitude_1')
NCDF_VARGET, fid, varid, longs
varid=NCDF_VARID(fid,'latitude_1')
NCDF_VARGET, fid, varid, lats
NCDF_CLOSE, fid

; select surface temperature and convert from Kelvin to Celsius
temp=data(*,*,0)-273.15
; Wrap the data around
temp=[temp,temp(0,*)]

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='blockfill.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
xsize=!D.X_VSIZE ;Paper x size
ysize=!D.Y_VSIZE ;Paper y size
xoffset=1000.
yoffset=4000.
myxsize=14000.
myysize=14000.
xstart=xoffset/xsize
xfinish=(xoffset+myxsize)/xsize
ystart=yoffset/ysize
yfinish=(yoffset+myysize)/ysize
!P.POSITION=[xstart, ystart, xfinish, yfinish]
;r = [255,0,0,0,0,0,66,184,245,255,255,255,230,191,148,105,161,184]
;g = [255,0,84,199,255,255,255,255,255,209,135,28,0,0,0,0,0,0]
;b = [255,0,255,255,255,178,0,0,0,0,0,0,0,0,0,20,135,186]
;TVLCT, r,g,b
d=[255, 255, 255,$ ;white
     0,   0,   0,$ ;black
     5, 112, 176,$
    54, 144, 192,$
   116, 169, 207,$
   166, 189, 219,$
   208, 189, 219,$
   236, 231, 242,$
   255, 247, 251,$
   255, 255, 204,$
   255, 237, 160,$
   254, 217, 118,$
   254, 178,  76,$
   253, 141,  60,$
   252,  78,  42,$
   227,  26,  28,$
   177,   0,  38]
c=reform(d, 3, N_ELEMENTS(d)/3)
TVLCT, c(0,*), c(1,*), c(2,*)

;Set the map projection
MAP_SET, 50.0, 0.0, /SATELLITE, /NOBORDER
longs=[longs,longs(N_ELEMENTS(longs)-1)+3.75]
levs=INDGEN(16)*4-28
levs(0)=-200
levs(15)=200
mylabs=INTARR(16)
mylabs(*)=1
mycols=INDGEN(16)+2

xinc=3.75
yinc=2.5

;Fill cells with colour
FOR ix=0,96 DO BEGIN
FOR iy=0,72 DO BEGIN
 ;Calculate the colour of the box 
 mycol=MAX(WHERE(temp(ix,iy) GE levs))
 ;calculate the limits of the bounding box
 xmin=ix*xinc-xinc/2.0
 xmax=ix*xinc+xinc/2.0
 ymin=iy*yinc-yinc/2.0
 ymax=iy*yinc+yinc/2.0
 myxcoords=[xmin, xmax,xmax,xmin,xmin]
 myycoords=90.0-[ymin,ymin,ymax,ymax,ymin]
 ;correct limits to be +/- 90 degrees
 pts=WHERE(myycoords GT 90.0,count)
 IF (count GT 0) THEN myycoords(pts)=90.0
 pts=WHERE(myycoords LT -90.0,count)
 IF (count GT 0) THEN myycoords(pts)=-90.0
 POLYFILL, myxcoords,myycoords, COLOR=mycol+2
ENDFOR
ENDFOR


; add the continents
MAP_CONTINENTS, /NOERASE

;Add a colourbar
COLBAR, [0.77,0.16,0.82,0.58], levs, 'Surface Temperature !Eo!NC', /UP, $
        /DOWN, /TEXTPOS

;Close the postscript file
DEVICE, /CLOSE
SPAWN, 'display blockfill.ps'

END
