PRO cylin2
; Program to show maps and pattern fill

; read in the data
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'temp')
NCDF_VARGET, fid, varid, data
varid=NCDF_VARID(fid,'longitude_1')
NCDF_VARGET, fid, varid, longs
varid=NCDF_VARID(fid,'latitude_1')
NCDF_VARGET, fid, varid, lats
NCDF_CLOSE, fid

; select surface temperature and convert from Kelvin to Celsius
temp=data(*,*,0)-273.15
; Wrap the data around
temp=[temp,temp(0,*)]
longs=[longs,longs(N_ELEMENTS(longs)-1)+3.75]

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='cylin2.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
!P.POSITION=[0.1,0.3,0.9,0.6]
r = [255,0,210,255]
g = [255,0,210,255]
b = [255,0,210,255]
TVLCT,r,g,b

;Set projection and contour the data
MAP_SET, 0.0, 0.0, LIMIT=[-90.0,-180.0,90.0,180.0], $
         /CONTINENTS, /CYLINDRICAL, /NOBORDER

;Shade below zero in grey	 
levs=[-100, 0]
labs=STRTRIM(STRING(levs),2)	
CONTOUR, temp, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         /CELL_FILL, C_COLORS=[2,3], /OVERPLOT
CONTOUR, temp, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         C_ANNOTATION=labs, /OVERPLOT	

;pattern fill between 25 and 60 degrees	 
levs=[25,60]
labs=STRTRIM(STRING(levs),2)
CONTOUR, temp, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         C_ORIENTATION=45.0, /CELL_FILL, /OVERPLOT
CONTOUR, temp, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         C_ANNOTATION=labs, /OVERPLOT	
	 
;Overlay the continents	   
MAP_CONTINENTS
	 
;Add the axes 
myticklen=-0.025
myticks=['180W', '150W', '120W','90W','60W','30W','GM','30E','60E',$
          '90E', '120E', '150E', '180E']
n=N_ELEMENTS(myticks)	  
mytickvals=FINDGEN(n)/(n-1)
AXIS, -180,-90, XAXIS=0, XTITLE='Longitude', TICKLEN=myticklen,$
         XTICKS=n-1, XTICKNAME=myticks, XTICKV=mytickvals
myticks(*)=' '
AXIS, -180,90, XAXIS=1, XTITLE=' ', TICKLEN=myticklen,$
         XTICKS=n-1, XTICKNAME=myticks, XTICKV=mytickvals
      
myticks=['90S','60S', '30S','EQ',$
         '30N','60N','90N']
n=N_ELEMENTS(myticks)	  
mytickvals=FINDGEN(n)/(n-1)
AXIS, -180,-90, YAXIS=0, YTITLE='Latitude', TICKLEN=myticklen/2.5,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals 
myticks(*)=' '      
AXIS, 180,-90, YAXIS=1, TICKLEN=myticklen/2.5,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals
	 
;Close the postscript file	 
DEVICE, /CLOSE
SPAWN, 'display cylin2.ps'

END

