PRO cylin3_triple
; Program to show  colour filled contours

; read in the data
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'temp')
NCDF_VARGET, fid, varid, data
NCDF_CLOSE, fid

; select surface temperature and convert from Kelvin to Celsius
temp=data(*,*,0)-273.15
; Wrap the data around
temp2=fltarr(97,73)
temp2(0:95,*)=temp
temp2(96,*)=temp2(0,*)

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='cylin3_triple.ps', XSIZE=8.0, YSIZE=11.0, $
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0

FOR i=0,2 DO BEGIN

!P.POSITION=[0.1,0.18+i*0.25,0.9,0.37+i*0.25]
r = [255,0,0,0,0,0,66,184,245,255,255,255,230,191,148,105,161,184]
g = [255,0,84,199,255,255,255,255,255,209,135,28,0,0,0,0,0,0]
b = [255,0,255,255,255,178,0,0,0,0,0,0,0,0,0,20,135,186]
TVLCT,r,g,b

lats=90.0-FINDGEN(73)*2.5   ; specify latitudes
longs=FINDGEN(97)*3.75      ; specify longitudes

;Set projection and contour the data
MAP_SET, 0.0, 0.0, LIMIT=[-90.0,-180.0,90.0,180.0], $
         /CONTINENTS, /CYLINDRICAL, /NOBORDER, /NOERASE
	
n=16
levs=INDGEN(n)*5-35       ; specify levels
levs(0)=-100
levs(n-1)=100
labs=STRTRIM(STRING(levs),2)
CONTOUR, temp2, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         /CELL_FILL, C_COLORS=INDGEN(n)+2, /OVERPLOT
CONTOUR, temp2, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         C_ANNOTATION=labs, /OVERPLOT	
MAP_CONTINENTS  ;overlay the continents

	 
;Add the axes 
myticklen=-0.025
myticks=['180W', '150W', '120W','90W','60W','30W','GM','30E','60E',$
          '90E', '120E', '150E', '180E']
n=N_ELEMENTS(myticks)	  
mytickvals=FINDGEN(n)/(n-1)
AXIS, -180,-90, XAXIS=0, XTITLE='Longitude', TICKLEN=myticklen,$
         XTICKS=n-1, XTICKNAME=myticks, XTICKV=mytickvals
myticks(*)=' '
AXIS, -180,90, XAXIS=1, XTITLE=' ', TICKLEN=myticklen,$
         XTICKS=n-1, XTICKNAME=myticks, XTICKV=mytickvals
      
myticks=['90S','60S', '30S','EQ',$
         '30N','60N','90N']
n=N_ELEMENTS(myticks)	  
mytickvals=FINDGEN(n)/(n-1)
AXIS, -180,-90, YAXIS=0, YTITLE='Latitude', TICKLEN=myticklen/2.5,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals 
myticks(*)=' '      
AXIS, 180,-90, YAXIS=1, TICKLEN=myticklen/2.5,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals

ENDFOR

	 
;Add a colourbar
COLBAR, [0.12,0.05,0.88,0.10], levs, 'Surface Temperature !Eo!NC', /LEFT, /RIGHT	

;Close the postscript file
DEVICE, /CLOSE

SPAWN, 'display cylin3_triple.ps'

END

