PRO hov
; Program to show plotting of a hovmuller plot

; read in the data
fid=NCDF_OPEN('u2.nc')
varid=NCDF_VARID(fid,'u')
NCDF_VARGET, fid, varid, u 
NCDF_CLOSE, fid
; select data either side of the equator and from 120W to 120E
u2=u(32:64,35:37,*,*)
; average over the three latitudes and use reform to collapse 
; array
u3=REFORM(TOTAL(u2, 2))

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='hov.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.POSITION=[0.1,0.3,0.7,0.6]
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
r = [255,0,0,0,0,0,66,184,245,255,255,255,230,191,148,105,161,184]
g = [255,0,84,199,255,255,255,255,255,209,135,28,0,0,0,0,0,0]
b = [255,0,255,255,255,178,0,0,0,0,0,0,0,0,0,20,135,186]
TVLCT, r,g,b


longs=FINDGEN(33)*3.75+120
days=INDGEN(200)
levs=-28+INDGEN(16)*4
levs(0)=-200.
levs(15)=200.
mycols=INDGEN(16)+2

;Contour the data
CONTOUR, u3, LEVELS=levs, XSTYLE=5, YSTYLE=5, /CELL_FILL,$
         C_COLORS=mycols 
CONTOUR, u3, LEVELS=[0.0], XSTYLE=5, YSTYLE=5, /OVERPLOT

;add a longitude axis
myticklen=-0.03
myticks=['120E', '150E','DL','150W', '120W']
mytickvals=[0,8,16,24,32]
AXIS, XAXIS=0, XTITLE='Longitude', TICKLEN=myticklen,$
         XTICKS=4, XTICKNAME=myticks, XTICKV=mytickvals
myticks(*)=' '
AXIS, XAXIS=1, TICKLEN=myticklen,$
         XTICKS=4, XTICKNAME=myticks, XTICKV=mytickvals


;add a time axis
myticklen=-0.015
myticks=[' ','Jan 1995','Feb 1995','Mar 1995','Apr 1995',$
         'May 1995','Jun 1995','Jul 1995']
mytickvals=[0,12,43,74,102,133,163,194]
AXIS, YAXIS=0,  YTITLE='Time', TICKLEN=myticklen,$
         YTICKS=7, YTICKNAME=myticks, YTICKV=mytickvals


;Add a zonal average to the right of the contour plot
!P.POSITION=[0.7,0.3,0.85,0.6]
npts=SIZE(u3)
ave=TOTAL(u3,1)/npts(1)
ypts=INDGEN(200)
PLOT, ave, ypts, XRANGE=[-20., 0.], XSTYLE=5, YSTYLE=5

;add the x axis
myticklen=-0.03
myticks=['-20', '-15','-10','-5', '0']
mytickvals=float(myticks)
AXIS, XAXIS=1, TICKLEN=myticklen,XTITLE='Zonal average ms!E-1!N',$
         XTICKS=4, XTICKNAME=myticks, XTICKV=mytickvals
myticks(*)=' '
AXIS, XAXIS=0, TICKLEN=myticklen,$
         XTICKS=4, XTICKNAME=myticks, XTICKV=mytickvals
	 

;And the y axes
myticks=[' ','Jan 1995','Feb 1995','Mar 1995','Apr 1995',$
         'May 1995','Jun 1995','Jul 1995']
mytickvals=[0,12,43,74,102,133,163,194]
AXIS, YAXIS=1, TICKLEN=myticklen,$
         YTICKS=7, YTICKNAME=myticks, YTICKV=mytickvals
	 
PLOTS, [-20,-20], [0,200] 
	 
	 
;Add a colour bar  
COLBAR, [0.1,0.19,0.69,0.23], levs, 'Zonal wind ms!E-1!N', /LEFT, /RIGHT

;Close the postscript file
DEVICE, /CLOSE
SPAWN, 'display hov.ps'

END
