PRO mdist
;Show model distributions on a map

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='mdist.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.POSITION=[0.1,0.3,0.9,0.6]
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
r = [255,0,255,235,153,0]
g = [255,0,255, 23,102,104]
b = [255,0,153,  0,255 ,55]
TVLCT,r,g,b


;Set projection and fill the continents with black
MAP_SET, 0.0, 0.0, -20., LIMIT=[-90.0,-180.0,90.0,180.0], $
	 /CYLINDRICAL, /NOBORDER
MAP_CONTINENTS, FILL_CONTINENTS=1, COLOR=5, /OVERPLOT

; Add the map border
y1=89.0
x1=179.9
x2=179.9
PLOTS,[-x1,-x1,x2,x2,-x1],[-y1,y1,y1,-y1,-y1]
;IDL gets confused crossing the GM so draw line incrementally.
FOR ix=0,359 DO BEGIN
  PLOTS, [ix,ix+1], [y1,y1]
ENDFOR

;Height of axis
myh=4000.0

;Add the z axis manually
xy=CONVERT_COORD([-180],[90], /DATA, /TO_DEVICE)	 
myticks=['zero', '1000','2000','3000','4000','5000','6000','7000']
mymax=7000.0
n=N_ELEMENTS(myticks)-1
myint=myh/n
ticklen=100

PLOTS, [xy(0),xy(0)],[xy(1),xy(1)+myint*n], /DEVICE
FOR iz=0,n DO BEGIN
  PLOTS, [xy(0)-ticklen, xy(0)],[xy(1)+iz*myint, xy(1)+iz*myint], /DEVICE
  XYOUTS, [xy(0)-ticklen*1.5], [xy(1)+iz*myint-100], myticks(iz), $
          ALIGNMENT=1.0, /DEVICE
ENDFOR
XYOUTS, xy(0)-ticklen*12,xy(1)+n/3*myint , 'No of runs', ORIENTATION=90.0, /DEVICE


;Add the towerblocks
xpts=[-110,0,102,-62,14,130] ; longitudes
ypts=[42,46,32,-25,5,-29] ; latitudes
vals=[2398,6872,4134,2701,1277,3253] ; tower block value

del=14.0 ; size of base in degrees
;Fill each face with colour and then add a border
!P.THICK=1.0
FOR i=0,N_ELEMENTS(xpts)-1 DO BEGIN
  ix=[xpts(i),xpts(i), xpts(i)+del, xpts(i)+del,xpts(i)]
  iy=[ypts(i),ypts(i)+del,ypts(i)+del, ypts(i),ypts(i)]
  xy=CONVERT_COORD(ix,iy, /DATA, /TO_DEVICE)
  POLYFILL, xy(0,*), xy(1,*)+vals(i)*myh/mymax, COLOR=4, /DEVICE
  
  PLOTS, xy(0,*), xy(1,*)+vals(i)*myh/mymax, /DEVICE
  
  
  fx=[xy(0,0), xy(0,0), xy(0,3), xy(0,3), xy(0,0)]
  
  fy=[xy(1,0), xy(1,0)+vals(i)*myh/mymax, xy(1,3)+vals(i)*myh/mymax, $
      xy(1,3), xy(1,0)]
  POLYFILL, fx, fy, /DEVICE, COLOR=3
  PLOTS, fx, fy, /DEVICE
  fx=[xy(0,0), xy(0,1), xy(0,1), xy(0,0), xy(0,0)]
  fy=[xy(1,0), xy(1,1), xy(1,1)+vals(i)*myh/mymax, $
      xy(1,0)+vals(i)*myh/mymax, xy(1,0)]
  POLYFILL, fx, fy, /DEVICE, COLOR=2
  PLOTS, fx, fy, /DEVICE
ENDFOR
	 
; Add title
XYOUTS, 0.45, 0.27, 'Model run distribution', /NORMAL	 

;Close the postscript file	 
DEVICE, /CLOSE
SPAWN, 'display mdist.ps'

END
