PRO moll
;Produce a composite Mollweide plot

;Read in the land-sea mask 
fid=NCDF_OPEN('lsmask.nc')
varid=NCDF_VARID(fid,'lsm')
NCDF_VARGET, fid, varid, lsm
NCDF_CLOSE, fid

;Read in the surface temperature and ice concentration
fid=NCDF_OPEN('n144_sfct_ice_sepmean.nc')
varid=NCDF_VARID(fid,'temp')
NCDF_VARGET, fid, varid, temp
varid=NCDF_VARID(fid,'iceconc')
NCDF_VARGET, fid, varid, iceconc
varid=NCDF_VARID(fid,'latitude')
NCDF_VARGET, fid, varid, lats
varid=NCDF_VARID(fid,'longitude')
NCDF_VARGET, fid, varid, longs
NCDF_CLOSE, fid

;Set the number of longitudes and latitudes
nx=N_ELEMENTS(longs)
ny=N_ELEMENTS(lats)

;Read in the cloud amount
fid=NCDF_OPEN('cloudammn.nc')
varid=NCDF_VARID(fid,'cldmn')
NCDF_VARGET, fid, varid, cld1
varid=NCDF_VARID(fid,'latitude')
NCDF_VARGET, fid, varid, cld_lats
varid=NCDF_VARID(fid,'longitude')
NCDF_VARGET, fid, varid, cld_longs
NCDF_CLOSE, fid

;Add an extra longitude to wrap the data
longs2=[longs,360.0]

;Find ocean and land points
ocean=WHERE(lsm LE 0.7)
land=WHERE(lsm GT 0.7)

;Convert to Celsius
t2=temp(*,*,0)-273.15

;Define an array to hold the colour values for the longitude
;latitude points
cols=INTARR(nx,ny)
;Initialise to be ice everywhere
cols(*,*)=2

;Fill in the land temperature points
t3=t2
t3(ocean)=-5000.
levs=FINDGEN(14)*5-35
levs(0)=-200.
FOR icol=0,13 DO BEGIN
pts=WHERE(t3 GE levs(icol))
cols(pts)=3+icol
ENDFOR

;Fill in the ocean temperature points
t3=t2
t3(land)=-5000.
levs=findgen(10)*2.5
FOR icol=0,9 DO BEGIN
pts=WHERE(t3 GE levs(icol))
cols(pts)=17+icol
ENDFOR

;Add the ice points
ice=WHERE(iceconc GT 0.0 AND iceconc LE 1.0)
cols(ice)=2

;Put the clouds on top
pts=WHERE(cld1 GT 1.0)
cld1(pts)=0.0
;cld3=CONGRID(cld1,288,217)/MAX(cld1)
cld2=FLTARR(288,217)
REGRID, cld1, cld_longs,cld_lats, cld2,longs, lats
cld2=cld2/MAX(cld1)

levs=findgen(10)/10.0*.8+0.2
FOR icol=0,9 DO BEGIN
pts=WHERE(cld2 GE levs(icol))
cols(pts)=27+icol
ENDFOR

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='moll.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.POSITION=[0.1,0.10,0.9,0.40]
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0

;Specify the colour tables
;Ice and land temperature
r1 = [255,  0,255,  0,  0,  0,  0, 66,184,245,255,255,255,230,191,148,184]
g1 = [255,  0,204, 84,199,255,255,255,255,255,209,135, 28,  0,  0,  0,  0]
b1 = [255,  0,204,255,255,255,178,  0,  0,  0,  0,  0,  0,  0,  0,  0,186]

;Ocean
r2 = [  0, 10, 17, 27, 51, 76, 92,102,122,150]     
g2 = [ 60, 73, 81, 93,120,144,150,176,197,227]    
b2 = [  0, 14, 27, 45, 79,115,121,156,186,226]  

;Cloud
grey = INDGEN(10)*12+135

;Combine these into one colour scale and load
r=INDGEN(17+10+10)
g=r
b=r
r(0:16)=r1
r(17:26)=r2
r(27:36)=grey
g(0:16)=g1
g(17:26)=g2
g(27:36)=grey
b(0:16)=b1
b(17:26)=b2
b(27:36)=grey
TVLCT,r,g,b

;Set the map projection
MAP_SET, 0.0, 0.0, LIMIT=[-90.0,-180.0,90.0,180.0], $
         /CONTINENTS, /MOLLWEIDE, /NOBORDER

;Plot the data
FOR ix=0, nx-1 DO BEGIN
FOR iy=0, ny-2 DO BEGIN
    xpts=[longs2(ix),longs2(ix),longs2(ix+1),longs2(ix+1),longs2(ix)]
    ypts=[lats(iy), lats(iy+1),lats(iy+1),lats(iy),lats(iy)]
      POLYFILL, xpts, ypts, COLOR=cols(ix,iy)
ENDFOR 
ENDFOR

;Overlay the continents
MAP_CONTINENTS

; Make a colourbar and labels
levs=STRARR(36)
levs(0)=' '
otemp=FINDGEN(10)*2.5
levs(1:14)=STRTRIM(STRING(INDGEN(14)*5-35),2)
levs(15:24)=STRTRIM(STRING(otemp, FORMAT='(f10.1)'),2)

;Add the colourbar and labels
COLBAR, [0.1,0.03,0.9,0.07], levs, ' ', /ALT
XYOUTS, 0.1,0.02, 'ICE', /NORMAL
XYOUTS, 0.27,0.02, 'LAND !Eo!NC', /NORMAL
XYOUTS, 0.5,0.02, 'OCEAN !Eo!NC', /NORMAL
XYOUTS, 0.77,0.02, 'CLOUD', /NORMAL

;Close the postscript file
DEVICE, /CLOSE
SPAWN, 'display moll.ps'

END
