PRO plot_six
; Program to show maps and contours

; read in the data
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'ht')
NCDF_VARGET, fid, varid, data
NCDF_CLOSE, fid

; select 100mb geopotential
geo=data(*,*,6)
; Wrap the data around
geo2=fltarr(97,73)
geo2(0:95,*)=geo
geo2(96,*)=geo2(0,*)

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='plot_six.ps',  XSIZE=8.0, YSIZE=11.0,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
FOR myx=0,1 DO BEGIN ;set up loop for x plotting position
FOR myy=0,2 DO BEGIN ;set up loop for y plotting position
;Do all the size calculations in device coordinates
xsize=!D.X_VSIZE ;Plot x size
ysize=!D.Y_VSIZE ;Plot y size
offset=1000.
mysize=6500.
spacing=900.
xstart=(offset*(myx+1)+spacing*myx+mysize*myx)
xfinish=(offset*(myx+1)+spacing*myx+mysize*(myx+1))
ystart=(offset*(myy+3)+mysize*myy)
yfinish=(offset*(myy+3)+mysize*(myy+1))

!P.POSITION=[xstart/xsize, ystart/ysize, xfinish/xsize, yfinish/ysize]
@mycols3

lats=90.0-FINDGEN(73)*2.5   ; specify latitudes
longs=FINDGEN(97)*3.75      ; specify longitudes

;Set projection and contour the data
MAP_SET, 90.0, 0.0, /STEREOGRAPHIC, /NOBORDER, /ADVANCE
n=13
levs=INDGEN(n)*150+15000      ; specify levels
levs(0)=0
levs(n-1)=30000
labs=STRTRIM(STRING(levs),2)
CONTOUR, geo2, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         /CELL_FILL, C_COLORS=INDGEN(n)+2, /OVERPLOT
CONTOUR, geo2, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         C_ANNOTATION=labs, /OVERPLOT	
	 
	 
;Overlay the continents	and grid  
MAP_CONTINENTS
MAP_GRID, LONDEL=30
	 
;Add the axes 
;First a line at the equator
FOR ix=0, 359 DO BEGIN
  PLOTS, [ix, ix+1], [0.1, 0.1]
ENDFOR

;Now swap into device coordinates to add the longitude labels
xmid=xstart+(xfinish-xstart)/2
ymid=ystart+(yfinish-ystart)/2
yrad=ymid-ystart
lonticks=['GM','30W','60W','90W','120W','150W',$
          'DL','150E','120E','90E','60E','30E' ]
	  
FOR ix=0,11 DO BEGIN
x=(yrad+300)*SIN(ix*30*!DTOR)
y=(yrad+300)*COS(ix*30*!DTOR)
XYOUTS, xmid-x, ymid-y-60, lonticks(ix), ALIGNMENT=0.5, /DEVICE
ENDFOR

ENDFOR
ENDFOR

; Add a colourbar
COLBAR, [0.1,0.0,0.74,0.03], levs,$
                 'Geopotential height(m)', /LEFT, /RIGHT, /ALT
	 
;Close the postscript file	 
DEVICE, /CLOSE

SPAWN, 'display plot_six.ps'

END
