PRO polar_winds
;Program to show winds over the pole

hem=1 ; 1=NH, -1=SH

;Vector defaults
type=2
maxmag=10
ref_pos=[0.8,0.05]
ref_text=STRTRIM(STRING(maxmag),2)+'ms!E-1!N'
length=2
angle=28.5
head_len=0.3
color=1
align=0.5

;Get the data
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'u')
NCDF_VARGET, fid, varid, u
varid=NCDF_VARID(fid,'v')
NCDF_VARGET, fid, varid, v
varid=NCDF_VARID(fid,'latitude')
NCDF_VARGET, fid, varid, lats
varid=NCDF_VARID(fid,'longitude')
NCDF_VARGET, fid, varid, longs
NCDF_CLOSE, fid
u=u(*,*,0)
v=v(*,*,0)
u(*,*)=7.07
v(*,*)=7.07
longs=[-1.877,longs] ; Wrap the longitides and data
u=[u(0,*),u]
v=[v(0,*),v]


;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='polar_winds.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
xsize=!D.X_VSIZE ;Paper x size
ysize=!D.Y_VSIZE ;Paper y size
xstart=(1000.)/xsize
xfinish=(1000.+18000.)/xsize
ystart=(2000.)/ysize
yfinish=(2000.+18000.)/ysize
!P.POSITION=[xstart, ystart, xfinish, yfinish]
r = [255,0,255]
g = [255,0,0]
b = [255,0,0]
TVLCT,r,g,b

;Set the projection 
MAP_SET, hem*90.0, 0.0, /STEREOGRAPHIC, /NOBORDER
MAP_CONTINENTS
	 
;Add a border at the equator
FOR ix=0, 359 DO BEGIN
  PLOTS, [ix, ix+1], [hem*0.1, hem*0.1]
ENDFOR

cen=CONVERT_COORD(0.0,hem*90.0, /DATA, /TO_DEVICE) ;Centre point
bottom=CONVERT_COORD(0.0,0.0, /DATA, /TO_DEVICE) ;Bottom of plot
myrad=ABS(cen(1)-bottom(1)) ;Radius in device coordinates

del=0.5 ; side of square for plotting box
npts=10 ; number of plotting points from equator to pole
FOR ix=-npts, npts DO BEGIN
FOR iy=-npts, npts DO BEGIN
  myx=cen(0)+ix*myrad/npts
  myy=cen(1)+iy*myrad/npts
  ;Select points that are within the plot
  IF (SQRT((myx-cen(0))^2+(myy-cen(1))^2) LT myrad) THEN BEGIN
  
     new=CONVERT_COORD(myx, myy, /DEVICE, /TO_DATA)
     xpts=[new(0)-del, new(0)-del, new(0)+del, new(0)+del, new(0)-del]
     ypts=[new(1)-del, new(1)+del, new(1)+del, new(1)-del, new(1)-del]

     mylong=new(0)
     IF (mylong LT 0) THEN mylong=360.0+mylong
     mylat=new(1)
     ;Find position and offset in longitude and latitude array
     newu=0.0
     newv=0.0
     REGRID, u, longs, lats, newu, mylong, mylat
     REGRID, v, longs, lats, newv, mylong, mylat 
    
     ;Determine u and v in device coordinate space
     udev=newu*cos(mylong*!dtor)-hem*newv*sin(mylong*!dtor)
     vdev=newv*cos(mylong*!dtor)+hem*newu*sin(mylong*!dtor)
    
     ;Plot the vector
     PLOT_VECTOR, udev, vdev, mylong, mylat, type=type, $
                  angle=angle, head_len=head_len,$
                  maxmag=maxmag, align=align, length=length,$
	          color=color, cstyle=0          
    
  ENDIF

ENDFOR
ENDFOR

MAP_GRID, LATDEL=30, LONDEL=30

;Plot a reference vector
PLOT_VECTOR, maxmag, 0.0, ref_pos[0], ref_pos[1], type=type, $
	     ref_text=ref_text, maxmag=maxmag, length=length,$
             angle=angle, head_len=head_len,$
             align=align, color=color, cstyle=1


;Close the postscript file	 
DEVICE, /CLOSE

SPAWN, 'display polar_winds.ps'

END
