PRO sector
; Program to show maps and contours

; read in the data
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'ht')
NCDF_VARGET, fid, varid, data
varid=NCDF_VARID(fid,'longitude_1')
NCDF_VARGET, fid, varid, longs
varid=NCDF_VARID(fid,'latitude_1')
NCDF_VARGET, fid, varid, lats
NCDF_CLOSE, fid

; select 100mb geopotential
geo=data(*,*,6)
; Wrap the data around
geo=[geo, geo(0,*)]
longs=[longs,longs(N_ELEMENTS(longs)-1)+3.75]

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='sector.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
xsize=!D.X_VSIZE ;Paper x size
ysize=!D.Y_VSIZE ;Paper y size
xoffset=4000.
yoffset=2000.
myxsize=14000.
myysize=14000.
xstart=xoffset/xsize
xfinish=(xoffset+myxsize)/xsize
ystart=yoffset/ysize
yfinish=(yoffset+myysize)/ysize
!P.POSITION=[xstart, ystart, xfinish, yfinish]
@mycols3

;Set projection and contour the data
latmax=90.0
latmin=25.0
longmax=45.0
longmin=-45.0
MAP_SET, 90.0, 0.0, LIMIT=[latmin, longmin,latmax,longmax], $
         /STEREO, /NOBORDER
n=13
levs=INDGEN(n)*150+15000      ; specify levels
levs(0)=0
levs(n-1)=30000
labs=STRTRIM(STRING(levs),2)
CONTOUR, geo, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         /CELL_FILL, C_COLORS=INDGEN(n)+2, /OVERPLOT
CONTOUR, geo, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         C_ANNOTATION=labs, /OVERPLOT	
	 
	 
;Overlay the continents	and grid  
MAP_CONTINENTS
MAP_GRID, LONDEL=10, LATDEL=10

;Overplot mask to get rid of extra plot area
FOR ix=-180,longmin-5,5 DO BEGIN
FOR iy=-90,90,5 DO BEGIN
    POLYFILL, [ix,ix,ix+5,ix+5,ix], [iy,iy+5,iy+5,iy,iy], COLOR=0
ENDFOR
ENDFOR
FOR ix=longmax,180,5 DO BEGIN
FOR iy=-90,90,5 DO BEGIN
  POLYFILL, [ix,ix,ix+5,ix+5,ix], [iy,iy+5,iy+5,iy,iy], COLOR=0
ENDFOR
ENDFOR
FOR ix=-180,180,5 DO BEGIN
FOR iy=-90,latmin,5 DO BEGIN
  POLYFILL, [ix,ix,ix+5,ix+5,ix], [iy,iy+5,iy+5,iy,iy], COLOR=0
ENDFOR
ENDFOR
FOR ix=-180,180,5 DO BEGIN
FOR iy=85, 90, 5 DO BEGIN
  POLYFILL, [ix,ix,ix+5,ix+5,ix], [iy,iy+5,iy+5,iy,iy], COLOR=0
ENDFOR
ENDFOR

;Add a border around the plot
FOR ix=-45, 40, 5 DO BEGIN
  PLOTS, [ix, ix+5], [85, 85]
  PLOTS, [ix, ix+5], [30, 30]
ENDFOR
FOR iy=30, 80, 5 DO BEGIN
  PLOTS, [-45, -45], [iy, iy+5]
  PLOTS, [45, 45], [iy, iy+5]
ENDFOR



; Add a colourbar
COLBAR, [0.16,0.12,0.24,0.50], levs,$
                 'Geopotential height(m)', /UP, /DOWN
	 
;Close the postscript file	 
DEVICE, /CLOSE

SPAWN, 'display sector.ps'

END
