PRO soi

;read in the data
fid=NCDF_OPEN('soi.nc')
varid=NCDF_VARID(fid,'SOI_SIGNAL')
NCDF_VARGET, fid,varid, soi_signal
varid=NCDF_VARID(fid,'TIME')
NCDF_VARGET, fid,varid, soi_time
NCDF_CLOSE, fid

sz=SIZE(soi_time,/N_ELEMENTS)
soi_signal2=FLTARR(sz)

; Select maximum and minimum for plot
mymax=3.0
mymin=-3.0

; Simply smooth the data
; A more complicated analysis is normally done.
soi_signal2=SMOOTH(soi_signal,6)
excess_pts=WHERE(soi_signal2 GT mymax)
IF (SIZE(excess_pts,/N_ELEMENTS) GT 0) THEN soi_signal2(excess_pts)=mymax
excess_pts=where(soi_signal2 lt mymin)
IF (SIZE(excess_pts,/N_ELEMENTS) GT 0) THEN soi_signal2(excess_pts)=mymin

;Open postscript file and select the color table
SET_PLOT,'ps'
DEVICE, FILE='soi.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
;set the colour table
r = [255,0,0,0,0,0,66,184,245,255,255,255,230,191,148,105,161,184]
g = [255,0,84,199,255,255,255,255,255,209,135,28,0,0,0,0,0,0]
b = [255,0,255,255,255,178,0,0,0,0,0,0,0,0,0,20,135,186]
TVLCT, r,g,b

!P.POSITION=[0.1,0.3,0.9,0.6]
!P.COLOR=1
!P.CHARSIZE=1.4
!P.CHARTHICK=3.0

;Colour red if positive and blue if negative
mypos=13
myneg=2
FOR i=0,sz-2 DO BEGIN
 x0=soi_time(i)
 x1=soi_time(i+1)
 y0=soi_signal2(i)
 y1=soi_signal2(i+1)
 xcoords=[x0,x0,x1,x1,x0]
 ycoords=[0.0,y0,y1,0.0,0.0]

; Both positive
IF ((soi_signal2(i) LT 0 ) AND (soi_signal2(i+1) LT 0 )) THEN BEGIN
 POLYFILL,xcoords, ycoords, COLOR=myneg
ENDIF

; Both negative
IF ((soi_signal2(i) GT 0 ) AND (soi_signal2(i+1) GT 0 )) THEN BEGIN
 POLYFILL,xcoords, ycoords, COLOR=mypos
ENDIF

; Graph line crossing over the zero line cases
IF ((soi_signal2(i) LT 0 ) AND (soi_signal2(i+1) GT 0 )) THEN BEGIN
 theta=ATAN((soi_signal2(i+1)-soi_signal2(i))/(soi_time(i+1)-soi_time(i)))
 a=0.0-soi_signal2(i)
 b=a/TAN(theta)
 x0=soi_time(i)
 x1=soi_time(i)+b
 y0=soi_signal2(i)
 y1=0.0
 xcoords=[x0,x0,x1,x1,x0]
 ycoords=[0.0,y0,y1,0.0,0.0]
 POLYFILL,xcoords, ycoords,COLOR=myneg
 x0=soi_time(i)+b
 x1=soi_time(i+1)
 y0=0.0
 y1=soi_signal2(i+1)
 xcoords=[x0,x0,x1,x1,x0]
 ycoords=[0.0,y0,y1,0.0,0.0]
 POLYFILL,xcoords, ycoords,COLOR=mypos
ENDIF

IF ((soi_signal2(i) GT 0 ) AND (soi_signal2(i+1) LT 0 )) THEN BEGIN
 theta=ATAN(-1.0*(soi_signal2(i+1)-soi_signal2(i))/(soi_time(i+1)-soi_time(i)))
 a=soi_signal2(i)
 b=a/TAN(theta)
 x0=soi_time(i)
 x1=soi_time(i)+b
 y0=soi_signal2(i)
 y1=0.0
 xcoords=[x0,x0,x1,x1,x0]
 ycoords=[0.0,y0,y1,0.0,0.0]
 POLYFILL,xcoords, ycoords, COLOR=mypos
 x0=soi_time(i)+b
 x1=soi_time(i+1)
 y0=0.0
 y1=soi_signal2(i+1)
 xcoords=[x0,x0,x1,x1,x0]
 ycoords=[0.0,y0,y1,0.0,0.0]
 POLYFILL,xcoords, ycoords, COLOR=myneg
ENDIF

ENDFOR

;plot the black graph line
PLOT, soi_time, soi_signal2, XSTYLE=5, YSTYLE=5, $
      YRANGE=[-3.0, 3.0], XRANGE=[1860, 2006], $
      TITLE='Oscillation index', /NOERASE



;Label the axes      
myticks=['1860', '1890', '1920','1950','1980']
myticklen=-0.03
mytickvals=FLOAT(myticks)
AXIS, XAXIS=0, XTITLE='Year', TICKLEN=myticklen,$
         XTICKS=4, XTICKNAME=myticks, XTICKV=mytickvals
myticks(*)=' '	 
AXIS, XAXIS=1, TICKLEN=myticklen,$
         XTICKS=4, XTICKNAME=myticks, XTICKV=mytickvals	 

n=7
mytickvals=INDGEN(n)-3
myticklen=-0.015
myticks=STRTRIM(STRING(mytickvals),2)
AXIS, YAXIS=0, YTITLE='Std. Anomalies', TICKLEN=myticklen,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals	 
myticks(*)=' '	 
AXIS, YAXIS=1, TICKLEN=myticklen,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals

;Close the postscript file
DEVICE, /CLOSE

SPAWN, 'display soi.ps'

END

