PRO sst

;Read in the data
fid=NCDF_OPEN('nemo.nc')
varid=NCDF_VARID(fid,'nav_lon')
NCDF_VARGET, fid, varid, longs
varid=NCDF_VARID(fid,'nav_lat')
NCDF_VARGET, fid,varid, lats
varid=NCDF_VARID(fid,'sosstsst')
NCDF_VARGET, fid,varid, sst
NCDF_CLOSE, fid


;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='sst.ps', XSIZE=8.27, YSIZE=11.69, $
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
r = [255,0,0,0,0,0,66,184,245,255,255,255,230,191,148,105,161,184]
g = [255,0,84,199,255,255,255,255,255,209,135,28,0,0,0,0,0,0]
b = [255,0,255,255,255,178,0,0,0,0,0,0,0,0,0,20,135,186]
TVLCT,r,g,b

;Set projection and draw the grid points
!P.POSITION=[0.1,0.6,0.9,0.9]
MAP_SET, 0.0, 0.0, LIMIT=[-90.0,-180.0,90.0,180.0], $
         /CONTINENTS, /CYLINDRICAL, /NOBORDER

FOR ix=0, 181 DO BEGIN
FOR iy=0, 148 DO BEGIN
  del=0.3
  minx=longs(ix,iy)-del
  maxx=longs(ix,iy)+del
  miny=lats(ix,iy)-del
  maxy=lats(ix,iy)+del
  xpts=[minx, minx, maxx, maxx, minx]
  ypts=[miny, maxy, maxy, miny, miny]
  POLYFILL, xpts, ypts, COLOR=10
ENDFOR
ENDFOR

;Add the axes 
myticklen=-0.025
myticks=['180W', '150W', '120W','90W','60W','30W','GM','30E','60E',$
          '90E', '120E', '150E', '180E']
n=N_ELEMENTS(myticks)	  
mytickvals=FINDGEN(n)/(n-1)
AXIS, -180,-90, XAXIS=0, XTITLE='Longitude', TICKLEN=myticklen,$
         XTICKS=n-1, XTICKNAME=myticks, XTICKV=mytickvals
myticks(*)=' '
AXIS, -180,90, XAXIS=1, XTITLE=' ', TICKLEN=myticklen,$
         XTICKS=n-1, XTICKNAME=myticks, XTICKV=mytickvals
      
myticks=['90S','60S', '30S','EQ',$
         '30N','60N','90N']
n=N_ELEMENTS(myticks)	  
mytickvals=FINDGEN(n)/(n-1)
AXIS, -180,-90, YAXIS=0, YTITLE='Latitude', TICKLEN=myticklen/2.5,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals 
myticks(*)=' '      
AXIS, 180,-90, YAXIS=1, TICKLEN=myticklen/2.5,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals
	 
	 
;Contour the data
!P.POSITION=[0.1,0.24,0.9,0.54]
MAP_SET, 0.0, 0.0, LIMIT=[-90.0,-180.0,90.0,180.0], $
         /CONTINENTS, /CYLINDRICAL, /NOBORDER, /NOERASE
	
n=16
levs=INDGEN(n)*2      ; specify levels
levs(0)=-100
levs(n-1)=100
labs=STRTRIM(STRING(levs),2)
TRIANGULATE, longs, lats, tri
CONTOUR, sst, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         /CELL_FILL, C_COLORS=INDGEN(n)+2, TRIANGULATION=tri, /OVERPLOT
MAP_CONTINENTS  ;overlay the continents

	 
;Add the axes 
myticklen=-0.025
myticks=['180W', '150W', '120W','90W','60W','30W','GM','30E','60E',$
          '90E', '120E', '150E', '180E']
n=N_ELEMENTS(myticks)	  
mytickvals=FINDGEN(n)/(n-1)
AXIS, -180,-90, XAXIS=0, XTITLE='Longitude', TICKLEN=myticklen,$
         XTICKS=n-1, XTICKNAME=myticks, XTICKV=mytickvals
myticks(*)=' '
AXIS, -180,90, XAXIS=1, XTITLE=' ', TICKLEN=myticklen,$
         XTICKS=n-1, XTICKNAME=myticks, XTICKV=mytickvals
      
myticks=['90S','60S', '30S','EQ',$
         '30N','60N','90N']
n=N_ELEMENTS(myticks)	  
mytickvals=FINDGEN(n)/(n-1)
AXIS, -180,-90, YAXIS=0, YTITLE='Latitude', TICKLEN=myticklen/2.5,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals 
myticks(*)=' '      
AXIS, 180,-90, YAXIS=1, TICKLEN=myticklen/2.5,$
         YTICKS=n-1, YTICKNAME=myticks, YTICKV=mytickvals
	 
;Add a colourbar
COLBAR, [0.12,0.14,0.88,0.18], levs, 'Surface Surface Temperature !Eo!NC', /LEFT, /RIGHT	

;Close the postscript file
DEVICE, /CLOSE
SPAWN, 'display sst.ps'
END
