PRO stereo
; Program to show maps and contours

; read in the data
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'ht')
NCDF_VARGET, fid, varid, data
varid=NCDF_VARID(fid,'longitude_1')
NCDF_VARGET, fid, varid, longs
varid=NCDF_VARID(fid,'latitude_1')
NCDF_VARGET, fid, varid, lats
NCDF_CLOSE, fid

; select 100mb geopotential
geo=data(*,*,6)
; Wrap the data around
geo=[geo, geo(0,*)]
longs=[longs,longs(N_ELEMENTS(longs)-1)+3.75]

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='stereo.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
xsize=!D.X_VSIZE ;Paper x size
ysize=!D.Y_VSIZE ;Paper y size
xoffset=4000.
yoffset=4000.
myxsize=14000.
myysize=14000.
xstart=xoffset/xsize
xfinish=(xoffset+myxsize)/xsize
ystart=yoffset/ysize
yfinish=(yoffset+myysize)/ysize
!P.POSITION=[xstart, ystart, xfinish, yfinish]
@mycols3

;Set projection and contour the data
MAP_SET, 90.0, 0.0, /STEREOGRAPHIC, /NOBORDER
n=13
levs=INDGEN(n)*150+15000      ; specify levels
levs(0)=0
levs(n-1)=30000
labs=STRTRIM(STRING(levs),2)
CONTOUR, geo, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         /CELL_FILL, C_COLORS=INDGEN(n)+2, /OVERPLOT
CONTOUR, geo, longs, lats, LEVELS=levs, XSTYLE=5, YSTYLE=5,$
         C_ANNOTATION=labs, /OVERPLOT	
	 
	 
;Overlay the continents	and grid  
MAP_CONTINENTS
MAP_GRID, LONDEL=30
	 
;Add the axes 
;First a line at the equator
FOR ix=0, 359 DO BEGIN
  PLOTS, [ix, ix+1], [0.1, 0.1]
ENDFOR

;Now swap into device coordinates to add the longitude labels
xmid=xoffset+myxsize/2
ymid=yoffset+myysize/2
yrad=myxsize/2
lonticks=['GM','30W','60W','90W','120W','150W',$
          'DL','150E','120E','90E','60E','30E' ]  
FOR ix=0,11 DO BEGIN
x=(yrad+400)*SIN(ix*30*!DTOR)
y=(yrad+400)*COS(ix*30*!DTOR)
XYOUTS, xmid-x, ymid-y-100, lonticks(ix), ALIGNMENT=0.5, /DEVICE
ENDFOR

; Add a colourbar
COLBAR, [0.08,0.12,0.16,0.50], levs,$
                 'Geopotential height(m)', /UP, /DOWN
	 
;Close the postscript file	 
DEVICE, /CLOSE

SPAWN, 'display stereo.ps'

END
