PRO winds_col
;Code to show wind vectors coloured with the temperature magnitude

;Vector defaults
type=0
maxmag=15
length=2
angle=28.5
head_len=0.3
color=1
align=0.5

;Get the data
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'u')
NCDF_VARGET, fid, varid, u
varid=NCDF_VARID(fid,'v')
NCDF_VARGET, fid, varid, v
varid=NCDF_VARID(fid,'temp')
NCDF_VARGET, fid, varid, t
varid=NCDF_VARID(fid,'longitude')
NCDF_VARGET, fid, varid, longs
varid=NCDF_VARID(fid,'latitude')
NCDF_VARGET, fid, varid, lats
NCDF_CLOSE, fid

;Open postscript file and select the color table
SET_PLOT,'ps'
DEVICE, FILE='winds_col.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
xsize=!D.X_VSIZE ;Paper x size
ysize=!D.Y_VSIZE ;Paper y size
xoffset=4000.
yoffset=4000.
myxsize=14000.
myysize=14000.
xstart=xoffset/xsize
xfinish=(xoffset+myxsize)/xsize
ystart=yoffset/ysize
yfinish=(yoffset+myysize)/ysize
!P.POSITION=[xstart, ystart, xfinish, yfinish]
cols=[255, 255, 255, $
        0,   0,   0, $
      153, 204, 255, $
      153, 204, 255, $
      115, 153, 255, $
       77, 102, 255, $
       39,  77, 217, $
        0,  51, 179, $
	0,  88, 146, $
	0, 128, 115, $
	0, 140,  57, $
	0, 153,   0, $
       30, 166,  30, $
       64, 179,  64, $
      129, 205,  67, $
      194, 232,  70, $
      223, 243,  35, $
      255, 255,   0, $
      255, 238,   0, $
      255, 223,   1, $
      255, 196,  37, $
      255, 168,  76, $
      255, 136,  52, $
      253, 104,  26, $
      243,  71,  13, $
      230,  38,   0, $
      210,  19,   0, $
      189,   0,   0, $
      172,   0,   0, $
      153,   0,   0, $
      220, 220, 220, $
      204, 255, 255, $
      0,     0,   0]      
c=reform(cols, 3, N_ELEMENTS(cols)/3)
TVLCT, c(0,*), c(1,*), c(2,*) 

;Set the map projection and colour everything light blue
MAP_SET, 60.0, -35.0,/SATELLITE, /NOBORDER
FOR ix=0,35 DO BEGIN
FOR iy=0,17 DO BEGIN
  xs=ix*10-180
  ys=iy*10-90
  POLYFILL, [xs,xs,xs+10,xs+10,xs], [ys,ys+9.99,ys+9.99,ys,ys], COLOR=31
ENDFOR
ENDFOR

;Add the continents and fill with black
MAP_CONTINENTS, FILL_CONTINENTS=1, COLOR=1, /OVERPLOT
MAP_CONTINENTS, /OVERPLOT
; add the grid
MAP_GRID

t=t(*,0:71)-273.15 ; rough and ready!
u=[u(*,*,0),u(0,*,0)]
v=[v(*,*,0),v(0,*,0)]
levs=INDGEN(28)*1.5-20.5
levs=INDGEN(28)*2-30

FOR iy=0, N_ELEMENTS(lats)-1 DO BEGIN
FOR ix=0, N_ELEMENTS(longs)-1 DO BEGIN
 mycol=size(where(t(ix,iy) ge levs), /n_elements)
 ;Plot the vector
 PLOT_VECTOR, u(ix,iy), v(ix,iy), longs(ix), lats(iy), type=type, $
	     angle=angle, head_len=head_len,$
	     maxmag=maxmag, align=align, length=length,$
   	     color=mycol+1, cstyle=0
ENDFOR
ENDFOR

cen=[xoffset+myxsize/2, yoffset+myysize/2] ;Centre point
bottom=yoffset ;Bottom of plot
myrad=myxsize/2 ;Radius in device coordinates
del=0.5 ; side of square for plotting box
npts=20 ; number of plotting points from equator to pole
;FOR ix=-npts, npts DO BEGIN
;FOR iy=-npts, npts DO BEGIN
;  myx=cen(0)+ix*myrad/npts
;  myy=cen(1)+iy*myrad/npts
  ;Select points that are within the plot
;  IF (SQRT((myx-cen(0))^2+(myy-cen(1))^2) LT myrad) THEN BEGIN
  
     ;new=CONVERT_COORD(myx, myy, /DEVICE, /TO_DATA)
     ;xpts=[new(0)-del, new(0)-del, new(0)+del, new(0)+del, new(0)-del]
     ;ypts=[new(1)-del, new(1)+del, new(1)+del, new(1)-del, new(1)-del]

     ;mylong=new(0)
     ;IF (mylong LT 0) THEN mylong=360.0+mylong
     ;mylat=new(1)
     ;Find position and offset in longitude and latitude array
     ;posx=FIX((mylong-1.875)/3.75)
     ;posy=FIX((88.75-mylat)/2.5)
     ;offsetx=((mylong-1.875)-posx*3.75)/3.75
     ;offsety=(88.75-mylat-posy*2.5)/2.5
    
     ;Do a bilinear interpolation to find the position u and v values
     ;IF (((posy GT 0) AND (posy LT N_ELEMENTS(lats)-1)) AND $
      ;  ((posx GT 0) AND (posx LT N_ELEMENTS(longs)-1))) THEN BEGIN
      ;PRINT, 'posx, posy are ', posx, posy
      
     ; p=u(posx:posx+1,posy:posy+1,0)
      ;newu=BILINEAR(p,offsetx, offsety)
      ;p=v(posx:posx+1,posy:posy+1,0)
      ;newv=BILINEAR(p,offsetx, offsety) 
     
      ;mycol=size(where(t(posx,posy) ge levs), /n_elements)
      ;Plot the vector
      ;PLOT_VECTOR, newu, newv, mylong, mylat, type=type,$
	;     angle=angle, head_len=head_len,$
	;     maxmag=maxmag, align=align, length=length,$
   	;     color=mycol, cstyle=0
    ; ENDIF               
    
  ;ENDIF

;ENDFOR
;ENDFOR

;Add the colourbar
COLBAR, [0.07,0.14,0.12,0.57], levs, 'Surface Temperature !Eo!NC', /UP, $
        /DOWN, /TEXTPOS

;Close the postscript file
DEVICE, /CLOSE
SPAWN, 'display winds_col.ps'

END

