PRO zonal
;Program to show a zonal wind plot

;Read the data and get the zonal average
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'u')
NCDF_VARGET, fid, varid, data
varid=NCDF_VARID(fid,'p')
NCDF_VARGET, fid, varid, plevs
varid=NCDF_VARID(fid,'latitude')
NCDF_VARGET, fid, varid, xpts
NCDF_CLOSE, fid
u=TOTAL(data,1)/96.0

;Open postscript file and select the color table
SET_PLOT, 'ps'
DEVICE, FILE='zonal.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.POSITION=[0.1,0.3,0.9,0.6]
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
@mycols2.pro

n=15    ;Specify the levels
levs=INDGEN(n)*5-30
levs(0)=-200
levs(n-1)=200
xpts=88.75-INDGEN(72)*2.5
ypts=FLOAT(plevs)

;Contour the data
CONTOUR, u,xpts,ypts, /CELL_FILL,$
         LEVELS=levs,C_COLORS=INDGEN(15)+2, XSTYLE=5, YSTYLE=5, $
         XRANGE=[90.0, -90.0], YRANGE=[1000.,0.316]
         
;Add a normal line contour plot with a thicker zero line
mythick=fltarr(n)
mythick(*)=3.0
mythick(6)=5.0
CONTOUR, u,xpts,ypts,$
         LEVELS=levs,C_ANNOTATION=STRTRIM(STRING(levs),2), $
	 C_THICK=mythick, /OVERPLOT
	 
;Label the axes
yticks=['1000', '750', '500', '250', '0.316']  
ytickvals=[1000., 750., 500., 250., 0.316]  
lats=['90', '60', '30','0','-30', '-60', '-90']
AXIS, XAXIS=0, TICKLEN=myticklen, XTITLE='Latitude', $
         XTICKS=6, XTICKNAME=lats, XTICKV=float(lats)
lats(*)=' '	 
AXIS, XAXIS=1, TICKLEN=myticklen,$
         XTICKS=6, XTICKNAME=lats, XTICKV=xtickvals

AXIS, YAXIS=0, YTITLE='Pressure (mb)', TICKLEN=myticklen,$
         YTICKS=4, YTICKNAME=yticks, YTICKV=float(yticks)

;Add a height axis on the rhs
levskm=[0, 2, 4, 6, 8, 10, 12, 20]
levsp=FLTARR(8)
FOR iz=0,7 DO BEGIN
  levsp(iz)=EXP(-1.0*(levskm(iz)/7.0-ALOG(1013.0)))
ENDFOR

AXIS, YAXIS=1, TICKLEN=myticklen,$
         YTICKS=7, YTICKNAME=STRTRIM(STRING(levskm),2), YTICKV=levsp,$
         YTITLE='Height (km)'


;Add a colourbar
COLBAR, [0.1,0.21,0.90,0.25], levs, 'Zonal wind ms!E-1!N', /LEFT, /RIGHT

;Close the postscript file
DEVICE, /CLOSE
SPAWN, 'display zonal.ps'

END

