PRO ZONAL2
;IDL code to show coverting y-axis to be logarithmic

;Read data and get the zonal mean
fid=NCDF_OPEN('ukmo.nc')
varid=NCDF_VARID(fid,'u')
NCDF_VARGET, fid, varid, data
varid=NCDF_VARID(fid,'p')
NCDF_VARGET, fid, varid, plevs
varid=NCDF_VARID(fid,'latitude')
NCDF_VARGET, fid, varid, xpts
NCDF_CLOSE, fid
u=TOTAL(data,1)/96.0

n=14
levs=INDGEN(n)*6-36
levs(0)=-200
levs(n-1)=200
ypticks=['1000', '250', '100', '50', '10', '1', '0.316']    
ykmticks=['0', '10','20','30', '40', '50','56.4']
lats=['90', '60', '30','0','-30', '-60', '-90']

;Convert mb to km
levskm=FLTARR(22)
FOR iz=0,21 DO BEGIN
  levskm(iz)=7.0*(ALOG(1013.)-ALOG(plevs(iz)))
ENDFOR

;Open postscript file and select the color table
SET_PLOT,'PS'
DEVICE, FILE='zonal2.ps', XSIZE=8.27, YSIZE=11.69,$
        XOFFSET=0.5, YOFFSET=0.5, /INCHES, /COLOR
!P.POSITION=[0.1,0.3,0.9,0.6]
!P.COLOR=1   
!P.THICK=3.0
!P.FONT=1
!X.THICK=3.0
!Y.THICK=3.0
;r = [255,0,0,0,0,0,66,184,245,255,255,255,230,191,148,105,161,184]
;g = [255,0,84,199,255,255,255,255,255,209,135,28,0,0,0,0,0,0]
;b = [255,0,255,255,255,178,0,0,0,0,0,0,0,0,0,20,135,186]
;TVLCT,r,g,b
@mycols2

;Contour the data
CONTOUR, u,xpts,levskm,/CELL_FILL,$
         LEVELS=levs,C_COLORS=INDGEN(15)+2,XSTYLE=5, YSTYLE=5, $
         XRANGE=[90.0, -90.0], YRANGE=[levskm(0),levskm(21)]
   	
; Add the axes    
AXIS, XAXIS=0, TICKLEN=myticklen, XTITLE='Latitude', $
         XTICKS=6, XTICKNAME=lats, XTICKV=float(lats)
lats(*)=' '
AXIS, XAXIS=1, TICKLEN=myticklen,$
         XTICKS=6, XTICKNAME=lats, XTICKV=xtickvals
	 
AXIS, YAXIS=0, YTITLE='Height (km)', TICKLEN=myticklen,$
         YTICKS=6, YTICKNAME=ykmticks, YTICKV=float(ykmticks)

levsptokm=FLTARR(7)
FOR iz=0,6 DO BEGIN
  levsptokm(iz)=7.0*(ALOG(1013.)-ALOG(ypticks(iz)))
ENDFOR
AXIS, YAXIS=1, TICKLEN=myticklen,$
         YTICKS=6, YTICKNAME=ypticks, YTICKV=levsptokm,$
         YTITLE='Pressure (mb)'
	 
;Add a colourbar
COLBAR, [0.1,0.21,0.90,0.25], levs,$
                 'Zonal wind ms!E-1!N', /LEFT, /RIGHT

;Add a normal line contour plot with a thicker zero line and 
;some extra levels below -36 celcius
n=18
levs=INDGEN(n)*6-66
mythick=fltarr(n)
mythick(*)=3.0
mythick(11)=5.0
CONTOUR, u,xpts,levskm,$
         LEVELS=levs, C_ANNOTATION=STRTRIM(STRING(levs),2), $
	 C_THICK=mythick, /OVERPLOT
	 
;Close the postscript file
DEVICE, /CLOSE
SPAWN, 'display zonal2.ps'

END


